%define ecllibdir           %{_libdir}/%{name}-%{version}

Name:           ecl
Version:        24.5.10
Release:        %mkrel 1
Summary:        Embeddable Common-Lisp
Group:          Development/Other
License:        LGPLv2+
URL:            https://common-lisp.net/project/ecl/
Source0:        https://common-lisp.net/project/ecl/static/files/release/ecl-%{version}.tgz
# A modified version of src/util/ecl.svg with extra whitespace removed.  The
# extra whitespace made the icon appear very small and shoved into a corner.
Source2:        %{name}.svg
# Metainfo for ECL
Source3:        net.common-lisp.ecl.metainfo.xml
# This patch was sent upstream on 4 Feb 2012.  It fixes a few warnings
# from the C compiler that indicate situations that might be dangerous at
# runtime.
Patch0:         %{name}-24.5.10-warnings.patch
# GCC does not implement support for #pragma STDC FENV_ACCESS
Patch2:         %{name}-24.5.10-fenv-access.patch
# Avoid an infinite loop if there is a write error on stderr.  See
# build/pkgs/ecl/patches/write_error.patch in the sagemath distribution.
Patch3:         %{name}-20.4.24-write-error.patch
# Fix bogus test compromised by LTO.
Patch4:         %{name}-20.4.24-configure.patch

Patch21:        ecl-fix-doc-build.patch

BuildRequires:	appstream
BuildRequires:  emacs-common
BuildRequires:  info-install
BuildRequires:  m4
BuildRequires:  texi2html
BuildRequires:  texinfo
BuildRequires:  texlive
BuildRequires:  pkgconfig(atomic_ops)
BuildRequires:  pkgconfig(bdw-gc)
BuildRequires:  pkgconfig(gmp) 
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(x11)

# ECL permits to mix C code and Lisp, so users probably want gcc and
# devel packages of libraries used by ecl
Recommends:       gcc
Recommends:       libgc-devel
Recommends:       gmp-devel

%description
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

# no -devel package for header files is split off
# since they are required by the main package

%package doc
Summary:      Documentation for Embeddable Common-Lisp
Group:        Development/Other
Requires:     %{name} = %{version}-%{release}

%description doc
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

This package contains the documentation for ECL.

%prep
%setup -q
%autopatch -p0

# Remove spurious executable bits
find src/{c,h} -type f -perm /0111 -exec chmod a-x {} \+

# Temporary fix for missing braces in initializers, causes build failure
sed -i 's/{.*,.*,.*,.*,.*}/{&}/g' src/c/symbols_list.h

# Don't give the library a useless rpath
sed -i "/ECL_LDRPATH='-Wl,--rpath,~A'/d" src/configure

%build
%configure \
        --enable-manual=html \
        --enable-threads=yes \
        --with-sse=auto \
        --enable-c99complex \
        --disable-rpath \
        CFLAGS="%{build_cflags} -Wno-unused -Wno-return-type -Wno-unknown-pragmas"

# Parallel make does not work
make

# documentation build broken
#(cd build/doc; make)

%install
%make_install

# documentation build broken
#(cd build/doc; %%make_install)

# remove wrongly installed files
rm -rf %{buildroot}%{_docdir}/
rm -rf %{buildroot}%{_libdir}/ecl-%{version}/{Copyright,LGPL}
rm -rf %{buildroot}/%{ecllibdir}/BUILD-STAMP

mkdir -p %{buildroot}/%{_datadir}/applications/
cat <<EOF > %{buildroot}/%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=ECL
GenericName=Common Lisp
Comment=Embeddable Common Lisp
Exec=ecl
Icon=ecl
Terminal=true
Type=Application
Categories=Development;Building;
EOF

# Install the desktop icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
cp -p %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

# Install the AppData file
mkdir -p %{buildroot}%{_metainfodir}
install -pm 644 %{SOURCE3} %{buildroot}%{_metainfodir}

find %{buildroot}%{ecllibdir} -name '*.lsp' -exec chmod 0644 {} \;

# Add missing executable bits
chmod a+x $RPM_BUILD_ROOT%{_libdir}/ecl-%{version}/dpp
chmod a+x $RPM_BUILD_ROOT%{_libdir}/ecl-%{version}/ecl_min

%files
%license COPYING LICENSE
%doc README*
%{_bindir}/ecl
%{_bindir}/ecl-config
%{ecllibdir}
%{_libdir}/libecl.so*
%{_includedir}/ecl
%{_mandir}/man*/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_metainfodir}/net.common-lisp.ecl.metainfo.xml

%files doc
%doc examples


%changelog
* Sun Nov 03 2024 papoteur <papoteur> 24.5.10-1.mga10
+ Revision: 2112303
- new version 24.5.10
- remove check with appstreamcli

* Fri Mar 03 2023 papoteur <papoteur> 21.2.1-3.mga9
+ Revision: 1946682
- Fix build documentation

* Sun Oct 30 2022 ghibo <ghibo> 21.2.1-2.mga9
+ Revision: 1900319
- Add missed appstream to BRs
- Fix typo in BRs
- More BRs
- Add emacs-common and libffi to BR
- Simplify configure options for other archs
- Update to release 21.2.1.
- Sync patchset with FC.
- Rework %%configure options.
- Add .svg icon.
- Add .desktop file.

* Fri Apr 01 2022 umeabot <umeabot> 16.1.3-3.mga9
+ Revision: 1839702
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 16.1.3-2.mga8
+ Revision: 1519437
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Oct 14 2018 wally <wally> 16.1.3-1.mga7
+ Revision: 1320228
- new version 16.1.3
- sync patches with Fedora

* Sun Sep 23 2018 umeabot <umeabot> 16.0.0-2.mga7
+ Revision: 1297559
- Mageia 7 Mass Rebuild

* Sun Feb 28 2016 wally <wally> 16.0.0-1.mga6
+ Revision: 980455
- new version 16.0.0
- sync patches and configure options with Fedora
- use our build time flags

* Sun Feb 28 2016 wally <wally> 13.5.1-8.mga6
+ Revision: 980412
- add patch from Fedora to fix stack direction detector (rhbz#1193134)

* Sun Feb 21 2016 umeabot <umeabot> 13.5.1-7.mga6
+ Revision: 975243
- Mageia 6 Mass Rebuild

* Mon Nov 09 2015 daviddavid <daviddavid> 13.5.1-5.mga6
+ Revision: 899850
- rebuild for new fixed libatomic_ops 7.4.2
- fix a syntax error into ecl-12.7.1-fdr-fix-atomic_ops.patch
  * /usr/lib(64)//libatomic_ops.a': No such file or directory

* Wed Oct 15 2014 umeabot <umeabot> 13.5.1-4.mga5
+ Revision: 750049
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 13.5.1-3.mga5
+ Revision: 678924
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Oct 19 2013 umeabot <umeabot> 13.5.1-2.mga4
+ Revision: 526001
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 13.5.1-1.mga4
+ Revision: 435396
- rediff P0
- rediff P2 and P3
- drop P1 sighandler.patch - merged upstream
- new version 13.5.1

* Fri Jan 11 2013 umeabot <umeabot> 12.12.1-2.mga3
+ Revision: 349311
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 kamil <kamil> 12.12.1-1.mga3
+ Revision: 333283
- disable Fedora patches
- update Source
- new version 12.12.1

* Mon Dec 03 2012 shlomif <shlomif> 12.7.1-1.mga3
+ Revision: 325910
- Fix build by making boehm-gc into the included one.
+ kamil <kamil>
- import patches (P0,1,2,3) from Fedora:
  * ecl-12.7.1-fdr-fix-atomic_ops.patch
  * ecl-12.7.1-fdr-sighandler.patch
  * ecl-12.7.1-fdr-signal_handling_thread.patch
  * ecl-12.7.1-fdr-warnings.patch

* Thu Apr 14 2011 tv <tv> 11.1.1-2.mga1
+ Revision: 85434
- imported package ecl


* Mon Apr 11 2011 Paulo Andrade <pcpa@mandriva.com.br> 11.1.1-2mdv2011.0
+ Revision: 652725
- Rebuild with gcc 4.6.0

* Thu Jan 27 2011 Paulo Andrade <pcpa@mandriva.com.br> 11.1.1-1
+ Revision: 633432
- Update to ecl 11.1.1.

* Sat Aug 07 2010 Paulo Andrade <pcpa@mandriva.com.br> 10.4.1-1mdv2011.0
+ Revision: 567221
- Update to version 10.0.4.1

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 9.12.3-2mdv2010.1
+ Revision: 503632
- rebuild for new gmp

* Tue Dec 15 2009 Frederik Himpe <fhimpe@mandriva.org> 9.12.3-1mdv2010.1
+ Revision: 479068
- update to new version 9.12.3

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 9.10.2-1mdv2010.1
+ Revision: 462184
- update to new version 9.10.2

* Tue Aug 18 2009 Frederik Himpe <fhimpe@mandriva.org> 9.8.4-1mdv2010.0
+ Revision: 417840
- update to new version 9.8.4

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 9.8.1-1mdv2010.0
+ Revision: 411752
- update to new version 9.8.1

* Thu Jul 16 2009 Paulo Andrade <pcpa@mandriva.com.br> 9.7.1-1mdv2010.0
+ Revision: 396514
- Update to latest upstream release.

* Sat Sep 27 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9j-6mdv2009.0
+ Revision: 288910
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 0.9j-5mdv2009.0
+ Revision: 244623
- rebuild

* Sat Feb 02 2008 Frederik Himpe <fhimpe@mandriva.org> 0.9j-3mdv2008.1
+ Revision: 161541
- Really fix ecl-doc requirement

* Sat Feb 02 2008 Frederik Himpe <fhimpe@mandriva.org> 0.9j-2mdv2008.1
+ Revision: 161480
- Fix requirements of doc package

* Sat Feb 02 2008 Frederik Himpe <fhimpe@mandriva.org> 0.9j-1mdv2008.1
+ Revision: 161459
- import ecl


